@@ -1,8 +1,8 @@
 <?php
 
 /**
- * This file is part of the Froxlor project.
- * Copyright (c) 2010 the Froxlor Team (see authors).
+ * This file is part of the froxlor project.
+ * Copyright (c) 2010 the froxlor Team (see authors).
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,7 +19,7 @@
  * https://files.froxlor.org/misc/COPYING.txt
  *
  * @copyright  the authors
- * @author     Froxlor team <team@froxlor.org>
+ * @author     froxlor team <team@froxlor.org>
  * @license    https://files.froxlor.org/misc/COPYING.txt GPLv2
  */
 
@@ -209,6 +209,14 @@ return [
 					'default' => 90,
 					'save_method' => 'storeSettingField'
 				],
+				'system_report_web_bccadmin' => [
+					'label' => lng('serversettings.report.report_web_bccadmin'),
+					'settinggroup' => 'system',
+					'varname' => 'report_web_bccadmin',
+					'type' => 'checkbox',
+					'default' => false,
+					'save_method' => 'storeSettingField'
+				],
 				'system_mail_use_smtp' => [
 					'label' => lng('serversettings.mail_use_smtp'),
 					'settinggroup' => 'system',
