@@ -1,8 +1,8 @@
 <?php
 
 /**
- * This file is part of the Froxlor project.
- * Copyright (c) 2010 the Froxlor Team (see authors).
+ * This file is part of the froxlor project.
+ * Copyright (c) 2010 the froxlor Team (see authors).
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,7 +19,7 @@
  * https://files.froxlor.org/misc/COPYING.txt
  *
  * @copyright  the authors
- * @author     Froxlor team <team@froxlor.org>
+ * @author     froxlor team <team@froxlor.org>
  * @license    https://files.froxlor.org/misc/COPYING.txt GPLv2
  */
 
@@ -162,7 +162,23 @@ return [
 					'string_emptyallowed' => true,
 					'save_method' => 'storeSettingField',
 					'advanced_mode' => true
-				]
+				],
+				'mail_enable_allow_sender' => [
+					'label' => lng('serversettings.mail_enable_allow_sender'),
+					'settinggroup' => 'mail',
+					'varname' => 'enable_allow_sender',
+					'type' => 'checkbox',
+					'default' => false,
+					'save_method' => 'storeSettingField'
+				],
+				'mail_allow_external_domains' => [
+					'label' => lng('serversettings.mail_allow_external_domains'),
+					'settinggroup' => 'mail',
+					'varname' => 'allow_external_domains',
+					'type' => 'checkbox',
+					'default' => false,
+					'save_method' => 'storeSettingField'
+				],
 			]
 		]
 	]
