@@ -1,8 +1,8 @@
 <?php
 
 /**
- * This file is part of the Froxlor project.
- * Copyright (c) 2010 the Froxlor Team (see authors).
+ * This file is part of the froxlor project.
+ * Copyright (c) 2010 the froxlor Team (see authors).
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,7 +19,7 @@
  * https://files.froxlor.org/misc/COPYING.txt
  *
  * @copyright  the authors
- * @author     Froxlor team <team@froxlor.org>
+ * @author     froxlor team <team@froxlor.org>
  * @license    https://files.froxlor.org/misc/COPYING.txt GPLv2
  */
 
@@ -93,7 +93,7 @@ class DirOptions extends ApiCommand implements ResourceEntity
 		// validation
 		$path = FileDir::makeCorrectDir(Validate::validate($path, 'path', Validate::REGEX_DIR, '', [], true));
 		$userpath = $path;
-		$path = FileDir::makeCorrectDir($customer['documentroot'] . '/' . $path);
+		$path = FileDir::makeCorrectDir($customer['documentroot'] . '/' . $path, $customer['documentroot']);
 
 		if (!empty($error404path)) {
 			$error404path = $this->correctErrorDocument($error404path, true);
@@ -177,17 +177,9 @@ class DirOptions extends ApiCommand implements ResourceEntity
 					}
 				} elseif (preg_match('/^"([^\r\n\t\f\0"]+)"$/', $errdoc)) {
 					// a string (check for ending ")
-					// string won't work for lighty
-					if (Settings::Get('system.webserver') == 'lighttpd') {
-						Response::standardError('stringerrordocumentnotvalidforlighty', '', $throw_exception);
-					}
 				} else {
 					Response::standardError('invaliderrordocumentvalue', '', $throw_exception);
 				}
-			} else {
-				if (Settings::Get('system.webserver') == 'lighttpd') {
-					Response::standardError('urlerrordocumentnotvalidforlighty', '', $throw_exception);
-				}
 			}
 		}
 		return trim($errdoc);
@@ -406,11 +398,12 @@ class DirOptions extends ApiCommand implements ResourceEntity
 		$customer_ids = $this->getAllowedCustomerIds('extras.pathoptions');
 
 		$result = [];
+		$query_fields = [];
 		$result_stmt = Database::prepare("
 			SELECT COUNT(*) as num_htaccess FROM `" . TABLE_PANEL_HTACCESS . "`
 			WHERE `customerid` IN (" . implode(', ', $customer_ids) . ")
-		");
-		$result = Database::pexecute_first($result_stmt, null, true, true);
+		" . $this->getSearchWhere($query_fields, true));
+		$result = Database::pexecute_first($result_stmt, $query_fields, true, true);
 		if ($result) {
 			return $this->response($result['num_htaccess']);
 		}
