@@ -1,8 +1,8 @@
 <?php
 
 /**
- * This file is part of the Froxlor project.
- * Copyright (c) 2010 the Froxlor Team (see authors).
+ * This file is part of the froxlor project.
+ * Copyright (c) 2010 the froxlor Team (see authors).
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,7 +19,7 @@
  * https://files.froxlor.org/misc/COPYING.txt
  *
  * @copyright  the authors
- * @author     Froxlor team <team@froxlor.org>
+ * @author     froxlor team <team@froxlor.org>
  * @license    https://files.froxlor.org/misc/COPYING.txt GPLv2
  */
 
@@ -43,9 +43,9 @@ final class PhpSessionclean extends CliCommand
 		$this->addArgument('max-lifetime', InputArgument::OPTIONAL, 'The number of seconds after which data will be seen as "garbage" and potentially cleaned up. Defaults to "1440"');
 	}
 
-	protected function execute(InputInterface $input, OutputInterface $output)
+	protected function execute(InputInterface $input, OutputInterface $output): int
 	{
-		$result = $this->validateRequirements($input, $output);
+		$result = $this->validateRequirements($output);
 
 		if ($result == self::SUCCESS) {
 			if ((int)Settings::Get('phpfpm.enabled') == 1) {
@@ -79,6 +79,13 @@ final class PhpSessionclean extends CliCommand
 				$pattern = preg_quote('session.save_path', '/');
 				$pattern = "/" . $pattern . ".+?\=(.*)/";
 				if (preg_match_all($pattern, $contents, $matches)) {
+					$session_path = trim($matches[1][0]);
+					// Skip non-file-based session storage (Redis, Memcached, etc.)
+					// These typically contain protocol indicators like :// or are not valid directories
+					if (strpos($session_path, '://') !== false) {
+						// Skip paths with protocol indicators (tcp://, redis://, memcached://, etc.)
+						continue;
+					}
 					$paths_to_clean[] = FileDir::makeCorrectDir(trim($matches[1][0]));
 				}
 			}
@@ -89,7 +96,7 @@ final class PhpSessionclean extends CliCommand
 
 		if (count($paths_to_clean) > 0) {
 			foreach ($paths_to_clean as $ptc) {
-				// find all files older then maxlifetime and delete them
+				// find all files older than maxlifetime and delete them
 				FileDir::safe_exec("find -O3 \"" . $ptc . "\" -ignore_readdir_race -depth -mindepth 1 -name 'sess_*' -type f -cmin \"+" . $maxlifetime . "\" -delete");
 			}
 		}
