@@ -1,8 +1,8 @@
 <?php
 
 /**
- * This file is part of the Froxlor project.
- * Copyright (c) 2010 the Froxlor Team (see authors).
+ * This file is part of the froxlor project.
+ * Copyright (c) 2010 the froxlor Team (see authors).
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,7 +19,7 @@
  * https://files.froxlor.org/misc/COPYING.txt
  *
  * @copyright  the authors
- * @author     Froxlor team <team@froxlor.org>
+ * @author     froxlor team <team@froxlor.org>
  * @license    https://files.froxlor.org/misc/COPYING.txt GPLv2
  */
 
@@ -33,6 +33,10 @@ class HttpClient
 	/**
 	 * Executes simple GET request
 	 *
+	 * @param string $url
+	 * @param bool $follow_location
+	 * @param int $timeout
+	 *
 	 * @return bool|string
 	 * @throws Exception
 	 */
@@ -49,16 +53,18 @@ class HttpClient
 		$output = curl_exec($ch);
 		if ($output === false) {
 			$e = curl_error($ch);
-			curl_close($ch);
 			throw new Exception("Curl error: " . $e);
 		}
-		curl_close($ch);
 		return $output;
 	}
 
 	/**
 	 * Downloads and stores a file from an url
 	 *
+	 * @param string $url
+	 * @param string $target
+	 *
+	 * @return bool|string
 	 * @throws Exception
 	 */
 	public static function fileGet(string $url, string $target)
@@ -75,10 +81,8 @@ class HttpClient
 		$output = curl_exec($ch);
 		if ($output === false) {
 			$e = curl_error($ch);
-			curl_close($ch);
 			throw new Exception("Curl error: " . $e);
 		}
-		curl_close($ch);
 		return $output;
 	}
 }
